"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = _default;

function _default() {
  return {
    name: "transform-remove-imports",
    visitor: {
      // https://babeljs.io/docs/en/babel-types#importdeclaration
      ImportDeclaration: function ImportDeclaration(path, state) {
        var node = path.node;
        var source = node.source;
        var opts = state.opts;

        if (opts.removeAll) {
          path.remove();
          return;
        }

        if (!opts.test) {
          console.warn("transform-remove-imports: \"test\" option should be specified");
          return;
        }
        /** @var {string} importName */


        var importName = source && source.value ? source.value : undefined;

        if (importName && testMatches(importName, opts.test)) {
          path.remove();
        }
      }
    }
  };
}
/**
 * Determines if the import matches the specified tests.
 *
 * @param {string} importName
 * @param {RegExp|RegExp[]|string|string[]} test
 */


function testMatches(importName, test) {
  // Normalizing tests
  var tests = Array.isArray(test) ? test : [test]; // Finding out if at least one test matches

  return tests.some(function (regex) {
    if (typeof regex === "string") {
      regex = new RegExp(regex);
    }

    return regex.test(importName);
  });
}